@@ -13,7 +13,7 @@ __dbus_send() {
         cur=${cur/*=/}
     fi
 
-    COMPREPLY=($(compgen -W "$(/2021Q3/libexec/dbus-bash-completion-helper dbus-send ${COMP_WORDS[@]:0})" -- $cur))
+    COMPREPLY=($(compgen -W "$(/usr/pkg/libexec/dbus-bash-completion-helper dbus-send ${COMP_WORDS[@]:0})" -- $cur))
 }
 
 ################################################################################
